﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using Syncfusion.Pdf;
using Syncfusion.Pdf.Parsing;
using Syncfusion.Pdf.Graphics;
using System.Drawing;

namespace Sample.Controllers
{
    public class HomeController : Controller
    {     
        public ActionResult Index()
        {
            //Create new PDF document. 
            PdfDocument document = new PdfDocument();

            //Set marging all 0. 
            document.PageSettings.Margins.All = 0;

            string fileName = Server.MapPath("~/App_Data/Sample.pdf");

            //Loads the input PDF document. 
            PdfLoadedDocument loadedDocument = new PdfLoadedDocument(fileName);
            for (int i = 0; i <= loadedDocument.Pages.Count - 1; i++)
            {
                document.PageSettings.Orientation = PdfPageOrientation.Landscape;
                document.PageSettings.Size = new SizeF(loadedDocument.Pages[0].Size.Height, loadedDocument.Pages[0].Size.Width);
                PdfPage page = document.Pages.Add();
                PdfGraphics g = page.Graphics;

                //Create PdfTeamplage of existing page. 
                PdfTemplate template = loadedDocument.Pages[i].CreateTemplate();

                //Get the rotation of the page. 
                PdfPageRotateAngle angle = loadedDocument.Pages[i].Rotation;

                //Rotate the page graphics 
                g.RotateTransform(GetRotationAngle(angle));
                g.TranslateTransform(-page.GetClientSize().Height, 0);
                g.Save();

                //Draw PdfTemplate in PdfPage. 
                g.DrawPdfTemplate(template, new PointF(0, 0), new SizeF(page.GetClientSize().Height, page.GetClientSize().Width));

                g.Restore();
            }                             

            //Save the PDF document.
            document.Save("output.pdf", HttpContext.ApplicationInstance.Response, HttpReadType.Open);

            return View();
        }

        private static float GetRotationAngle(PdfPageRotateAngle angle)
        {
            float m_angle = 0;
            switch (angle)
            {
                case PdfPageRotateAngle.RotateAngle90:
                    m_angle = 90;
                    break;
                case PdfPageRotateAngle.RotateAngle180:
                    m_angle = 180;
                    break;
                case PdfPageRotateAngle.RotateAngle270:
                    m_angle = 270;
                    break;
            }
            return m_angle;
        }
    }
}